@@ -45,18 +45,18 @@ class Fortyeight : public DealerScene
 
 public:
     explicit Fortyeight( const DealerInfo * di );
-    void initialize() Q_DECL_OVERRIDE;
+    void initialize() override;
 
 protected:
-    void setGameState( const QString & state ) Q_DECL_OVERRIDE;
-    QString getGameState() const Q_DECL_OVERRIDE;
-    bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const Q_DECL_OVERRIDE;
-    bool checkRemove(const PatPile* pile, const QList<KCard*> & cards) const Q_DECL_OVERRIDE;
-    void cardsDroppedOnPile( const QList<KCard*> & cards, KCardPile * pile ) Q_DECL_OVERRIDE;
-    void restart( const QList<KCard*> & cards ) Q_DECL_OVERRIDE;
+    void setGameState( const QString & state ) override;
+    QString getGameState() const override;
+    bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const override;
+    bool checkRemove(const PatPile* pile, const QList<KCard*> & cards) const override;
+    void cardsDroppedOnPile( const QList<KCard*> & cards, KCardPile * pile ) override;
+    void restart( const QList<KCard*> & cards ) override;
 
 protected slots:
-    bool newCards() Q_DECL_OVERRIDE;
+    bool newCards() override;
 
 private:
     bool canPutStore( const KCardPile * pile, const QList<KCard*> &cards ) const;
