@@ -259,7 +259,7 @@ public:
       : DealerInfo(I18N_NOOP("Aces Up"), AcesUpId)
     {}
 
-    DealerScene *createGame() const Q_DECL_OVERRIDE
+    DealerScene *createGame() const override
     {
         return new Idiot( this );
     }
