@@ -765,7 +765,11 @@ void KCardScene::recalculatePileLayouts()
 
 void KCardScene::setHighlightedItems( const QList<QGraphicsItem*> &items )
 {
-    QSet<QGraphicsItem*> s = QSet<QGraphicsItem*>::fromList( items );
+#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
+    const QSet<QGraphicsItem*> s = QSet<QGraphicsItem*>::fromList( items );
+#else
+    const QSet<QGraphicsItem*> s = QSet<QGraphicsItem*>(items.cbegin(), items.cend());
+#endif
     foreach ( QGraphicsItem * i, d->highlightedItems.subtract( s ) )
         setItemHighlight( i, false );
     foreach ( QGraphicsItem * i, s )
@@ -784,7 +788,7 @@ void KCardScene::clearHighlightedItems()
 
 QList<QGraphicsItem*> KCardScene::highlightedItems() const
 {
-    return d->highlightedItems.toList();
+    return d->highlightedItems.values();
 }
 
 
